/// <reference types="react" />
import type { Reducer } from 'redux';
export declare const UNSUPPORTED_COLUMNSTORE_INDEX_OPTIONS: OptionNames[];
export declare const OPTIONS: {
    readonly unique: {
        readonly type: "checkbox";
        readonly label: "Create unique index";
        readonly description: "A unique index ensures that the indexed fields do not store duplicate values; i.e. enforces uniqueness for the indexed fields.";
    };
    readonly name: {
        readonly type: "text";
        readonly label: "Index name";
        readonly description: "Enter the name of the index to create, or leave blank to have MongoDB create a default name for the index.";
        readonly units: undefined;
        readonly optional: true;
    };
    readonly expireAfterSeconds: {
        readonly type: "number";
        readonly label: "Create TTL";
        readonly description: "TTL indexes are special single-field indexes that MongoDB can use to automatically remove documents from a collection after a certain amount of time or at a specific clock time.";
        readonly units: "seconds";
        readonly optional: false;
    };
    readonly partialFilterExpression: {
        readonly type: "code";
        readonly label: "Partial Filter Expression";
        readonly description: "Partial indexes only index the documents in a collection that meet a specified filter expression.";
        readonly units: undefined;
        readonly optional: false;
    };
    readonly wildcardProjection: {
        readonly type: "code";
        readonly label: "Wildcard Projection";
        readonly description: "Wildcard indexes support queries against unknown or arbitrary fields.";
        readonly units: undefined;
        readonly optional: false;
    };
    readonly collation: {
        readonly type: "code";
        readonly label: "Use Custom Collation";
        readonly description: "Collation allows users to specify language-specific rules for string comparison, such as rules for lettercase and accent marks.";
        readonly units: undefined;
        readonly optional: false;
    };
    readonly columnstoreProjection: {
        readonly type: "code";
        readonly label: JSX.Element;
        readonly description: "Columnstore indexes support queries against unknown or arbitrary fields.";
        readonly units: undefined;
        readonly optional: false;
    };
    readonly sparse: {
        readonly type: "checkbox";
        readonly label: "Create sparse index";
        readonly description: "Sparse indexes only contain entries for documents that have the indexed field, even if the index field contains a null value. The index skips over any document that is missing the indexed field.";
    };
};
export declare type OptionNames = keyof typeof OPTIONS;
export declare type CheckboxOptions = {
    [k in OptionNames]: typeof OPTIONS[k]['type'] extends 'checkbox' ? k : never;
}[OptionNames];
export declare type InputOptions = Exclude<OptionNames, CheckboxOptions>;
declare type State = {
    [k in OptionNames]: {
        enabled: boolean;
    } & (typeof OPTIONS[k]['type'] extends 'checkbox' ? {
        value: boolean;
    } : {
        value: string;
    });
};
declare type ValueForOption<O extends OptionNames> = typeof OPTIONS[O]['type'] extends 'checkbox' ? boolean : string;
declare enum Actions {
    ChangeOption = "compass-indexes/create-index/change-option",
    ChangeOptionEnabled = "compass-indexes/create-index/change-option-enabled"
}
declare type ChangeOptionAction<O extends OptionNames = OptionNames> = {
    type: Actions.ChangeOption;
    name: O;
    value: ValueForOption<O>;
};
export declare function changeOption<O extends OptionNames>(optionName: O, newValue: ValueForOption<O>): ChangeOptionAction<O>;
declare type ChangeOptionEnabledAction<O extends OptionNames = OptionNames> = {
    type: Actions.ChangeOptionEnabled;
    name: O;
    enabled: boolean;
};
export declare function changeOptionEnabled<O extends OptionNames>(optionName: O, enabled: boolean): ChangeOptionEnabledAction<O>;
export declare const INITIAL_STATE: State;
declare const reducer: Reducer<State>;
export default reducer;
//# sourceMappingURL=options.d.ts.map